@@ -61,7 +61,7 @@ SelectConfiguration::SelectConfiguration(AtlanticCore *atlanticCore, TQWidget *p
 	m_backButton = new KPushButton(SmallIcon("back"), i18n("Leave Game"), this);
 	serverButtons->addWidget(m_backButton);
 
-	connect(m_backButton, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(leaveGame()));
+	connect(m_backButton, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(leaveGame()));
 
 	serverButtons->addItem(new TQSpacerItem(20, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum));
 
@@ -69,11 +69,11 @@ SelectConfiguration::SelectConfiguration(AtlanticCore *atlanticCore, TQWidget *p
 	serverButtons->addWidget(m_startButton);
 	m_startButton->setEnabled(false);
 
-	connect(m_startButton, TQT_SIGNAL(clicked()), this, TQT_SIGNAL(startGame()));
+	connect(m_startButton, TQ_SIGNAL(clicked()), this, TQ_SIGNAL(startGame()));
 
 	Player *playerSelf = m_atlanticCore->playerSelf();
 	playerChanged(playerSelf);
-	connect(playerSelf, TQT_SIGNAL(changed(Player *)), this, TQT_SLOT(playerChanged(Player *)));
+	connect(playerSelf, TQ_SIGNAL(changed(Player *)), this, TQ_SLOT(playerChanged(Player *)));
 
 	emit statusMessage(i18n("Retrieving configuration list..."));
 }
@@ -94,8 +94,8 @@ void SelectConfiguration::addConfigOption(ConfigOption *configOption)
 	checkBox->setEnabled( configOption->edit() && m_atlanticCore->selfIsMaster() );
 	checkBox->show();
 
-	connect(checkBox, TQT_SIGNAL(clicked()), this, TQT_SLOT(changeOption()));
-	connect(configOption, TQT_SIGNAL(changed(ConfigOption *)), this, TQT_SLOT(optionChanged(ConfigOption *)));
+	connect(checkBox, TQ_SIGNAL(clicked()), this, TQ_SLOT(changeOption()));
+	connect(configOption, TQ_SIGNAL(changed(ConfigOption *)), this, TQ_SLOT(optionChanged(ConfigOption *)));
 }
 
 void SelectConfiguration::gameOption(TQString title, TQString type, TQString value, TQString edit, TQString command)
@@ -118,7 +118,7 @@ void SelectConfiguration::gameOption(TQString title, TQString type, TQString val
 		checkBox->setEnabled(edit.toInt());
 		checkBox->show();
 
-		connect(checkBox, TQT_SIGNAL(clicked()), this, TQT_SLOT(optionChanged()));
+		connect(checkBox, TQ_SIGNAL(clicked()), this, TQ_SLOT(optionChanged()));
 	}
 	// TODO: create options other than type=bool
 
@@ -171,12 +171,12 @@ void SelectConfiguration::playerChanged(Player *player)
 		kdDebug() << "playerChanged::change" << endl;
 
 		if (m_game)
-			disconnect(m_game, TQT_SIGNAL(changed(Game *)), this, TQT_SLOT(gameChanged(Game *)));
+			disconnect(m_game, TQ_SIGNAL(changed(Game *)), this, TQ_SLOT(gameChanged(Game *)));
 
 		m_game = player->game();
 
 		if (m_game)
-			connect(m_game, TQT_SIGNAL(changed(Game *)), this, TQT_SLOT(gameChanged(Game *)));
+			connect(m_game, TQ_SIGNAL(changed(Game *)), this, TQ_SLOT(gameChanged(Game *)));
 	}
 }
 
