@@ -79,10 +79,10 @@ KAstTopLevel::KAstTopLevel()
     mainWin->setFixedSize(640, 480);
 
     view = new KAsteroidsView( mainWin );
-    connect( view, TQT_SIGNAL( shipKilled() ), TQT_SLOT( slotShipKilled() ) );
-    connect( view, TQT_SIGNAL( rockHit(int) ), TQT_SLOT( slotRockHit(int) ) );
-    connect( view, TQT_SIGNAL( rocksRemoved() ), TQT_SLOT( slotRocksRemoved() ) );
-    connect( view, TQT_SIGNAL( updateVitals() ), TQT_SLOT( slotUpdateVitals() ) );
+    connect( view, TQ_SIGNAL( shipKilled() ), TQ_SLOT( slotShipKilled() ) );
+    connect( view, TQ_SIGNAL( rockHit(int) ), TQ_SLOT( slotRockHit(int) ) );
+    connect( view, TQ_SIGNAL( rocksRemoved() ), TQ_SLOT( slotRocksRemoved() ) );
+    connect( view, TQ_SIGNAL( updateVitals() ), TQ_SLOT( slotUpdateVitals() ) );
 
     TQVBoxLayout *vb = new TQVBoxLayout( mainWin );
     TQHBoxLayout *hb = new TQHBoxLayout;
@@ -252,7 +252,7 @@ KAstTopLevel::KAstTopLevel()
 		
     setupGUI( TDEMainWindow::Save | Create );
     
-		setFocusPolicy( TQ_StrongFocus );
+		setFocusPolicy( TQWidget::StrongFocus );
     setFocus();
 
 #ifdef KA_ENABLE_SOUND
@@ -280,14 +280,14 @@ KAstTopLevel::~KAstTopLevel()
 void KAstTopLevel::initTDEAction()
 {
 // game
-    KStdGameAction::gameNew( TQT_TQOBJECT(this), TQT_SLOT( slotNewGame() ), actionCollection() );
-    KStdGameAction::highscores( TQT_TQOBJECT(this), TQT_SLOT( slotShowHighscores() ), actionCollection() );
-    KStdGameAction::pause( TQT_TQOBJECT(this), TQT_SLOT( slotPause() ), actionCollection() );
-    KStdGameAction::quit(TQT_TQOBJECT(this), TQT_SLOT( close() ), actionCollection());
+    KStdGameAction::gameNew( this, TQ_SLOT( slotNewGame() ), actionCollection() );
+    KStdGameAction::highscores( this, TQ_SLOT( slotShowHighscores() ), actionCollection() );
+    KStdGameAction::pause( this, TQ_SLOT( slotPause() ), actionCollection() );
+    KStdGameAction::quit(this, TQ_SLOT( close() ), actionCollection());
 
 // settings
-    KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT( slotKeyConfig() ), actionCollection());
-    KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT( slotPref() ), actionCollection());
+    KStdAction::keyBindings(this, TQ_SLOT( slotKeyConfig() ), actionCollection());
+    KStdAction::preferences(this, TQ_SLOT( slotPref() ), actionCollection());
 
 // keyboard-only actions
     keycodes.insert(Thrust, new TDEAction(i18n("Thrust"), TQt::Key_Up, 0, 0, actionCollection(), "Thrust"));
@@ -297,7 +297,7 @@ void KAstTopLevel::initTDEAction()
 //     keycodes.insert(Teleport, new TDEAction(i18n("Teleport"), TQt::Key_Z, 0, 0, actionCollection(), "Teleport"));
     keycodes.insert(Brake, new TDEAction(i18n("Brake"), TQt::Key_X, 0, 0, actionCollection(), "Brake"));
     keycodes.insert(Shield, new TDEAction(i18n("Shield"), TQt::Key_S, 0, 0, actionCollection(), "Shield"));
-    launchAction = new TDEAction(i18n("Launch"), TQt::Key_L, TQT_TQOBJECT(this), TQT_SLOT(slotLaunch()), actionCollection(), "Launch");
+    launchAction = new TDEAction(i18n("Launch"), TQt::Key_L, this, TQ_SLOT(slotLaunch()), actionCollection(), "Launch");
 }
 
 
@@ -336,7 +336,7 @@ return; // remove this and the above when the sound below is working correctly
 
 bool KAstTopLevel::eventFilter( TQObject* /* object */, TQEvent *event )
 {
-	TQKeyEvent *e = TQT_TQKEYEVENT(event);
+	TQKeyEvent *e = static_cast<TQKeyEvent*>(event);
 	if (event->type() == TQEvent::AccelOverride)
 	{
 		if (processKeyPress(e)) return true;
@@ -529,7 +529,7 @@ void KAstTopLevel::slotShipKilled()
         }
         else
         {
-           TQTimer::singleShot(1000, TQT_TQOBJECT(this), TQT_SLOT(slotGameOver()));
+           TQTimer::singleShot(1000, this, TQ_SLOT(slotGameOver()));
         }
     }
 }
@@ -613,7 +613,7 @@ void KAstTopLevel::slotPref()
   /* Done */
 
   dialog->addPage(w, i18n("General"), "package_settings");
-  connect(dialog, TQT_SIGNAL(settingsChanged()), TQT_TQOBJECT(this), TQT_SLOT(loadSettings()));
+  connect(dialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(loadSettings()));
   dialog->show();
 }
 
@@ -641,7 +641,7 @@ void KAstTopLevel::doStats()
       .arg(view->shots() - view->hits())
       .arg(r);
 
-    view->showText( s, green, FALSE );
+    view->showText( s, green, false );
 }
 
 void KAstTopLevel::slotUpdateVitals()
