@@ -91,7 +91,7 @@ KAsteroidsView::KAsteroidsView( TQWidget *parent, const char *name )
     readSprites();
 
     shieldTimer = new TQTimer( this );
-    connect( shieldTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(hideShield()) );
+    connect( shieldTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(hideShield()) );
     mTimerId = -1;
 
     shipPower = MAX_POWER_LEVEL;
