@@ -28,7 +28,7 @@
 #endif
 
 #include <kgame/kgame.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 class TQObject;
 class KPlayer;
 
@@ -36,9 +36,9 @@ class KPlayer;
  *
  *
  */
-class KDE_EXPORT KBgGame : public KGame
+class TDE_EXPORT KBgGame : public KGame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
