@@ -173,9 +173,9 @@ void KBgBoardSetup::getSetupPages(KDialogBase *nb)
 	blc->addWidget(pbc_3, 0, 1);
 	blc->addMultiCellWidget(pbc_1, 1, 1, 0, 1);
 
-	connect(pbc_1, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectBackgroundColor()));
-	connect(pbc_2, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectBaseColorOne()));
-	connect(pbc_3, TQT_SIGNAL(clicked()), this, TQT_SLOT(selectBaseColorTwo()));
+	connect(pbc_1, TQ_SIGNAL(clicked()), this, TQ_SLOT(selectBackgroundColor()));
+	connect(pbc_2, TQ_SIGNAL(clicked()), this, TQ_SLOT(selectBaseColorOne()));
+	connect(pbc_3, TQ_SIGNAL(clicked()), this, TQ_SLOT(selectBaseColorTwo()));
 
 	/*
 	 * Moving style
@@ -470,11 +470,11 @@ KBgBoardQCube::KBgBoardQCube(int val, bool us, bool them)
 
 	cb[0]->setFocus();
 
-	connect(ok,     TQT_SIGNAL(clicked()), TQT_SLOT(accept()));
-	connect(cancel, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+	connect(ok,     TQ_SIGNAL(clicked()), TQ_SLOT(accept()));
+	connect(cancel, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 
-	connect(cb[0],  TQT_SIGNAL(activated(int)), TQT_SLOT(changePlayer(int)));
-	connect(cb[1],  TQT_SIGNAL(activated(int)), TQT_SLOT(changeValue (int)));
+	connect(cb[0],  TQ_SIGNAL(activated(int)), TQ_SLOT(changePlayer(int)));
+	connect(cb[1],  TQ_SIGNAL(activated(int)), TQ_SLOT(changeValue (int)));
 }
 
 /*
@@ -576,8 +576,8 @@ KBgBoardQDice::KBgBoardQDice(const char *name)
 
 	sb[0]->setFocus();
 
-	connect(ok,     TQT_SIGNAL(clicked()), TQT_SLOT(accept()));
-	connect(cancel, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
+	connect(ok,     TQ_SIGNAL(clicked()), TQ_SLOT(accept()));
+	connect(cancel, TQ_SIGNAL(clicked()), TQ_SLOT(reject()));
 
 	sb[0]->setValue(1);
 	sb[1]->setValue(1);
@@ -1102,7 +1102,7 @@ void KBgBoardHome::drawDiceFrame(TQPainter *p, int col, int num,
  */
 void KBgBoardCell::mousePressEvent(TQMouseEvent *e)
 {
-	if (e->button() == Qt::RightButton)
+	if (e->button() == TQt::RightButton)
 		board->showContextMenu();
 	else
 		mouseButton = e->button();
@@ -1141,7 +1141,7 @@ int KBgBoard::getShortMoveMode()
  */
 void KBgBoardCell::checkAndMakeShortMove(TQMouseEvent *e, int m)
 {
-	if ((e->button() == Qt::LeftButton) &&
+	if ((e->button() == TQt::LeftButton) &&
 	    (board->getShortMoveMode() == m) &&
 	    (dragPossible()) &&
 	    (!board->getEditMode()))
@@ -1317,7 +1317,7 @@ int KBgBoard::getPipCount(const int& w) const
  */
 void KBgBoardHome::mouseDoubleClickEvent(TQMouseEvent * e)
 {
-	if (e->button() != Qt::LeftButton)
+	if (e->button() != TQt::LeftButton)
 		return;
 	/*
 	 * Check whether this is the bookkeeping home...
@@ -1745,10 +1745,10 @@ KBgBoardCell::KBgBoardCell(TQWidget * parent, int numID)
 	stateChanged     = false;
 	colorChanged     = false;
 	directionChanged = false;
-	mouseButton      = Qt::NoButton;
+	mouseButton      = TQt::NoButton;
 	dragInProgress   = false;
 
-	connect(parent, TQT_SIGNAL(finishedUpdate()), this, TQT_SLOT(refresh()));
+	connect(parent, TQ_SIGNAL(finishedUpdate()), this, TQ_SLOT(refresh()));
 }
 
 /*
@@ -2150,7 +2150,7 @@ void KBgBoard::setState(const KBgStatus &st)
  */
 void KBgBoardCell::mouseMoveEvent(TQMouseEvent *)
 {
-	if ((mouseButton == Qt::LeftButton) && dragPossible()) {
+	if ((mouseButton == TQt::LeftButton) && dragPossible()) {
 		dragInProgress = true;
 		TQRect cr(0, 0, 1+getCheckerDiameter(), 1+getCheckerDiameter());
 		cr.moveBottomLeft(rect().bottomLeft());
@@ -2169,7 +2169,7 @@ void KBgBoardCell::mouseMoveEvent(TQMouseEvent *)
 			board->storeTurn(pcs);
 		getPiece();
 	}
-	mouseButton = Qt::NoButton;
+	mouseButton = TQt::NoButton;
 }
 
 /*
