@@ -27,7 +27,7 @@ class Listener {
 
 class Network: public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
     
  public:
