@@ -16,7 +16,7 @@ class TQLabel;
 
 class Spy: public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
