@@ -33,7 +33,7 @@ class KIntNumInput;
 //-----------------------------------------------------------------------------
 class Smiley : public TQPushButton, public KMines
 {
- Q_OBJECT
+ TQ_OBJECT
   
  public:
     Smiley(TQWidget *parent, const char *name = 0)
@@ -49,7 +49,7 @@ class Smiley : public TQPushButton, public KMines
 //-----------------------------------------------------------------------------
 class DigitalClock : public KGameLCDClock
 {
- Q_OBJECT
+ TQ_OBJECT
   
  public:
     DigitalClock(TQWidget *parent);
@@ -77,7 +77,7 @@ class DigitalClock : public KGameLCDClock
 //-----------------------------------------------------------------------------
 class CustomConfig : public TQWidget, public KMines
 {
- Q_OBJECT
+ TQ_OBJECT
   
  public:
     CustomConfig();
@@ -102,7 +102,7 @@ class CustomConfig : public TQWidget, public KMines
 //-----------------------------------------------------------------------------
 class GameConfig : public TQWidget, public KMines
 {
- Q_OBJECT
+ TQ_OBJECT
   
  public:
     GameConfig();
@@ -121,7 +121,7 @@ class GameConfig : public TQWidget, public KMines
 
 class AppearanceConfig : public TQWidget, public KMines
 {
- Q_OBJECT
+ TQ_OBJECT
   
  public:
     AppearanceConfig();
