@@ -5,7 +5,7 @@
 
 class Config : public TQFrame
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -25,7 +25,7 @@ protected:
 // this is easy to use to show a message
 class MessageConfig : public Config
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -35,7 +35,7 @@ public:
 // internal
 class DefaultConfig : public MessageConfig
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
