@@ -48,17 +48,17 @@ static int default_colors=3;
 KSameWidget::KSameWidget(TQWidget *parent, const char* name, WFlags fl) :
              TDEMainWindow(parent,name,fl)
 {
-	KStdGameAction::gameNew(TQT_TQOBJECT(this), TQT_SLOT(m_new()), actionCollection(), "game_new");
-	restart = new TDEAction(i18n("&Restart This Board"), CTRL+Key_R, TQT_TQOBJECT(this),
-						  TQT_SLOT(m_restart()), actionCollection(), "game_restart");
-	KStdGameAction::highscores(TQT_TQOBJECT(this), TQT_SLOT(m_showhs()), actionCollection(), "game_highscores");
-	KStdGameAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection(), "game_quit");
-	undo = KStdGameAction::undo(TQT_TQOBJECT(this), TQT_SLOT(m_undo()), actionCollection(), "edit_undo");
+	KStdGameAction::gameNew(this, TQ_SLOT(m_new()), actionCollection(), "game_new");
+	restart = new TDEAction(i18n("&Restart This Board"), CTRL+Key_R, this,
+						  TQ_SLOT(m_restart()), actionCollection(), "game_restart");
+	KStdGameAction::highscores(this, TQ_SLOT(m_showhs()), actionCollection(), "game_highscores");
+	KStdGameAction::quit(this, TQ_SLOT(close()), actionCollection(), "game_quit");
+	undo = KStdGameAction::undo(this, TQ_SLOT(m_undo()), actionCollection(), "edit_undo");
 
 	random = new TDEToggleAction(i18n("&Random Board"), 0, 0, 0, actionCollection(), "random_board");
-	showNumberRemaining = new TDEToggleAction(i18n("&Show Number Remaining"), 0, TQT_TQOBJECT(this), TQT_SLOT(showNumberRemainingToggled()), actionCollection(), "showNumberRemaining");
+	showNumberRemaining = new TDEToggleAction(i18n("&Show Number Remaining"), 0, this, TQ_SLOT(showNumberRemainingToggled()), actionCollection(), "showNumberRemaining");
 
-	KStdAction::configureNotifications(TQT_TQOBJECT(this), TQT_SLOT(configureNotifications()),
+	KStdAction::configureNotifications(this, TQ_SLOT(configureNotifications()),
                actionCollection());
 
 	status=statusBar();
@@ -69,14 +69,14 @@ KSameWidget::KSameWidget(TQWidget *parent, const char* name, WFlags fl) :
 
 	stone = new StoneWidget(this,15,10);
 
-	connect( stone, TQT_SIGNAL(s_gameover()), TQT_TQOBJECT(this), TQT_SLOT(gameover()));
-	connect( stone, TQT_SIGNAL(s_colors(int)), TQT_TQOBJECT(this), TQT_SLOT(setColors(int)));
-	connect( stone, TQT_SIGNAL(s_board(int)), TQT_TQOBJECT(this), TQT_SLOT(setBoard(int)));
-	connect( stone, TQT_SIGNAL(s_marked(int)), TQT_TQOBJECT(this), TQT_SLOT(setMarked(int)));
-	connect( stone, TQT_SIGNAL(s_score(int)), TQT_TQOBJECT(this), TQT_SLOT(setScore(int)));
-	connect( stone, TQT_SIGNAL(s_remove(int,int)), TQT_TQOBJECT(this), TQT_SLOT(stonesRemoved(int,int)));
+	connect( stone, TQ_SIGNAL(s_gameover()), this, TQ_SLOT(gameover()));
+	connect( stone, TQ_SIGNAL(s_colors(int)), this, TQ_SLOT(setColors(int)));
+	connect( stone, TQ_SIGNAL(s_board(int)), this, TQ_SLOT(setBoard(int)));
+	connect( stone, TQ_SIGNAL(s_marked(int)), this, TQ_SLOT(setMarked(int)));
+	connect( stone, TQ_SIGNAL(s_score(int)), this, TQ_SLOT(setScore(int)));
+	connect( stone, TQ_SIGNAL(s_remove(int,int)), this, TQ_SLOT(stonesRemoved(int,int)));
 
-	connect(stone, TQT_SIGNAL(s_sizechanged()), TQT_TQOBJECT(this), TQT_SLOT(sizeChanged()));
+	connect(stone, TQ_SIGNAL(s_sizechanged()), this, TQ_SLOT(sizeChanged()));
 
 	sizeChanged();
 	setCentralWidget(stone);
