@@ -32,7 +32,7 @@ class Rattler;
 
 class View : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
 	View ( TQWidget *parent=0, const char *name=0 );
