@@ -64,7 +64,7 @@ void MPInterface::dialog()
 
 	// net meeting
 	TQPtrList<RemoteHostData> rhd;
-	rhd.setAutoDelete(TRUE);
+	rhd.setAutoDelete(true);
 	if (cd.network) {
 		cId id(kapp->name(), gameInfo.gameId);
 		MPOptionWidget *ow = newOptionWidget();
@@ -110,8 +110,8 @@ void MPInterface::specialLocalGame(uint nbHumans, uint nbAIs)
 					   : i18n("AI %1").arg(i-nbHumans+1));
 		cd.rhd.bds += bd;
 	}
-	cd.server  = TRUE;
-	cd.network = FALSE;
+	cd.server  = true;
+	cd.network = false;
 	Q_ASSERT( (nbHumans+nbAIs)<=gameInfo.maxNbLocalPlayers );
 	Q_ASSERT( gameInfo.AIAllowed || nbAIs==0 );
 
@@ -255,7 +255,7 @@ void MPInterface::hostDisconnected(uint, const TQString &msg)
 	errorBox(msg, TQString(), this);
 
 	if ( !disconnected ) { // to avoid multiple calls
-		disconnected = TRUE;
+		disconnected = true;
 		// the zero timer is used to be outside the "internal" class
 		TQTimer::singleShot(0, this, TQ_SLOT(singleHumanSlot()));
 	}
@@ -263,7 +263,7 @@ void MPInterface::hostDisconnected(uint, const TQString &msg)
 
 void MPInterface::singleHumanSlot()
 {
-	disconnected = FALSE;
+	disconnected = false;
 	singleHuman();
 }
 
