@@ -26,8 +26,8 @@ KCanvasRootPixmap::KCanvasRootPixmap(TQCanvasView *view, const char *name)
     : KRootPixmap(view, name), _view(view)
 {
     setCustomPainting(true);
-    connect(this, TQT_SIGNAL(backgroundUpdated(const TQPixmap &)),
-            TQT_SLOT(backgroundUpdatedSlot(const TQPixmap &)));
+    connect(this, TQ_SIGNAL(backgroundUpdated(const TQPixmap &)),
+            TQ_SLOT(backgroundUpdatedSlot(const TQPixmap &)));
 }
 
 void KCanvasRootPixmap::backgroundUpdatedSlot(const TQPixmap &pixmap)
