@@ -206,8 +206,8 @@ void KChatBase::init(bool noComboBox)
  TQVBoxLayout* l = new TQVBoxLayout(this);
 
  d->mBox = new TQListBox(this);
- connect(d->mBox, TQT_SIGNAL(rightButtonClicked(TQListBoxItem*, const TQPoint&)), 
-		this, TQT_SIGNAL(rightButtonClicked(TQListBoxItem*, const TQPoint&)));
+ connect(d->mBox, TQ_SIGNAL(rightButtonClicked(TQListBoxItem*, const TQPoint&)), 
+		this, TQ_SIGNAL(rightButtonClicked(TQListBoxItem*, const TQPoint&)));
  l->addWidget(d->mBox);
  d->mBox->setVScrollBarMode(TQScrollView::AlwaysOn);
  d->mBox->setHScrollBarMode(TQScrollView::AlwaysOff);
@@ -223,7 +223,7 @@ void KChatBase::init(bool noComboBox)
  d->mEdit->setTrapReturnKey(true);
  d->mEdit->completionObject(); // add the completion object
  d->mEdit->setCompletionMode(TDEGlobalSettings::CompletionNone);
- connect(d->mEdit, TQT_SIGNAL(returnPressed(const TQString&)), this, TQT_SLOT(slotReturnPressed(const TQString&)));
+ connect(d->mEdit, TQ_SIGNAL(returnPressed(const TQString&)), this, TQ_SLOT(slotReturnPressed(const TQString&)));
  h->addWidget(d->mEdit);
 
  if (!noComboBox) {
@@ -399,7 +399,7 @@ void KChatBase::slotReturnPressed(const TQString& text)
 	return;
  }
  d->mEdit->completionObject()->addItem(text);
-// connect(d->mEdit, TQT_SIGNAL(returnPressed(const TQString&)), comp, TQT_SLOT(addItem(const TQString&)));
+// connect(d->mEdit, TQ_SIGNAL(returnPressed(const TQString&)), comp, TQ_SLOT(addItem(const TQString&)));
  d->mEdit->clear();
  returnPressed(text);
 }
