@@ -82,7 +82,7 @@ ChatDlg::ChatDlg(KGame *game,TQWidget *parent)
  adjustSize();
 
  mChatDlg=new KChatDialog(mChat,plainPage(),true);
- connect(mButton,TQT_SIGNAL(clicked()),mChatDlg,TQT_SLOT(show()));
+ connect(mButton,TQ_SIGNAL(clicked()),mChatDlg,TQ_SLOT(show()));
 }
 
 /**
@@ -188,50 +188,50 @@ void Kwin4App::checkMenus(CheckFlags menu)
  */
 void Kwin4App::initGUI()
 {
-  KStdGameAction::gameNew(TQT_TQOBJECT(this), TQT_SLOT(newGame()), actionCollection(), "new_game");
+  KStdGameAction::gameNew(this, TQ_SLOT(newGame()), actionCollection(), "new_game");
   ACTION("new_game")->setStatusText(i18n("Start a new game"));
 
-  KStdGameAction::load(TQT_TQOBJECT(this), TQT_SLOT(slotOpenGame()), actionCollection(), "open");
+  KStdGameAction::load(this, TQ_SLOT(slotOpenGame()), actionCollection(), "open");
   ACTION("open")->setStatusText(i18n("Open a saved game..."));
 
-  KStdGameAction::save(TQT_TQOBJECT(this), TQT_SLOT(slotSaveGame()), actionCollection(), "save");
+  KStdGameAction::save(this, TQ_SLOT(slotSaveGame()), actionCollection(), "save");
   ACTION("save")->setStatusText(i18n("Save a game..."));
 
-  KStdGameAction::end(TQT_TQOBJECT(this), TQT_SLOT(endGame()), actionCollection(), "end_game");
+  KStdGameAction::end(this, TQ_SLOT(endGame()), actionCollection(), "end_game");
   ACTION("end_game")->setStatusText(i18n("Ending the current game..."));
   ACTION("end_game")->setWhatsThis(i18n("Aborts a currently played game. No winner will be declared."));
 
-  new TDEAction(i18n("&Network Configuration..."),0, TQT_TQOBJECT(this), TQT_SLOT(slotInitNetwork()),
+  new TDEAction(i18n("&Network Configuration..."),0, this, TQ_SLOT(slotInitNetwork()),
                        actionCollection(), "network_conf");
 
-  new TDEAction(i18n("Network Chat..."),0, TQT_TQOBJECT(this), TQT_SLOT(slotChat()),
+  new TDEAction(i18n("Network Chat..."),0, this, TQ_SLOT(slotChat()),
                        actionCollection(), "network_chat");
 
   if (global_debug>0)                     
-    new TDEAction(i18n("Debug KGame"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotDebugKGame()),
+    new TDEAction(i18n("Debug KGame"), 0, this, TQ_SLOT(slotDebugKGame()),
                         actionCollection(), "file_debug");
 
-  new TDEAction(i18n("&Show Statistics"),"flag", 0, TQT_TQOBJECT(this),
-           TQT_SLOT(showStatistics()), actionCollection(), "statistics");
+  new TDEAction(i18n("&Show Statistics"),"flag", 0, this,
+           TQ_SLOT(showStatistics()), actionCollection(), "statistics");
   ACTION("statistics")->setStatusText(i18n("Show statistics."));
 
-  KStdGameAction::hint(TQT_TQOBJECT(doc), TQT_SLOT(calcHint()), actionCollection(), "hint");
+  KStdGameAction::hint(doc, TQ_SLOT(calcHint()), actionCollection(), "hint");
   ACTION("hint")->setStatusText(i18n("Shows a hint on how to move."));
 
-  KStdGameAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection(), "game_exit");
+  KStdGameAction::quit(this, TQ_SLOT(close()), actionCollection(), "game_exit");
   ACTION("game_exit")->setStatusText(i18n("Quits the program."));
 
-  KStdGameAction::undo(TQT_TQOBJECT(this), TQT_SLOT(slotUndo()), actionCollection(), "edit_undo");
+  KStdGameAction::undo(this, TQ_SLOT(slotUndo()), actionCollection(), "edit_undo");
   ACTION("edit_undo")->setStatusText(i18n("Undo last move."));
 
-  KStdGameAction::redo(TQT_TQOBJECT(this), TQT_SLOT(slotRedo()), actionCollection(), "edit_redo");
+  KStdGameAction::redo(this, TQ_SLOT(slotRedo()), actionCollection(), "edit_redo");
   ACTION("edit_redo")->setStatusText(i18n("Redo last move."));
   
   actionCollection()->setHighlightingEnabled(true);
-  connect(actionCollection(), TQT_SIGNAL(actionStatusText(const TQString &)), TQT_SLOT(slotStatusMsg(const TQString &)));
-  connect(actionCollection(), TQT_SIGNAL(clearStatusText()), TQT_SLOT(slotClearStatusText()));
+  connect(actionCollection(), TQ_SIGNAL(actionStatusText(const TQString &)), TQ_SLOT(slotStatusMsg(const TQString &)));
+  connect(actionCollection(), TQ_SIGNAL(clearStatusText()), TQ_SLOT(slotClearStatusText()));
 
-  KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(showSettings()), actionCollection());
+  KStdAction::preferences(this, TQ_SLOT(showSettings()), actionCollection());
 }
 
 /**
@@ -263,17 +263,17 @@ void Kwin4App::initDocument()
 {
   doc = new Kwin4Doc(this);
   // Game Over signal
-  connect(doc,TQT_SIGNAL(signalGameOver(int, KPlayer *,KGame *)),
-         this,TQT_SLOT(slotGameOver(int, KPlayer *,KGame *)));
-  connect(doc,TQT_SIGNAL(signalMoveDone(int, int)),
-         this,TQT_SLOT(slotMoveDone(int, int)));
-  connect(doc,TQT_SIGNAL(signalClientLeftGame(int, int,KGame *)),
-         this,TQT_SLOT(slotNetworkBroken(int, int, KGame *)));
-  connect(doc,TQT_SIGNAL(signalNextPlayer()),
-         this,TQT_SLOT(slotStatusNames()));
+  connect(doc,TQ_SIGNAL(signalGameOver(int, KPlayer *,KGame *)),
+         this,TQ_SLOT(slotGameOver(int, KPlayer *,KGame *)));
+  connect(doc,TQ_SIGNAL(signalMoveDone(int, int)),
+         this,TQ_SLOT(slotMoveDone(int, int)));
+  connect(doc,TQ_SIGNAL(signalClientLeftGame(int, int,KGame *)),
+         this,TQ_SLOT(slotNetworkBroken(int, int, KGame *)));
+  connect(doc,TQ_SIGNAL(signalNextPlayer()),
+         this,TQ_SLOT(slotStatusNames()));
 
-  connect(doc,TQT_SIGNAL(signalGameRun()),
-         this,TQT_SLOT(slotNewGame()));
+  connect(doc,TQ_SIGNAL(signalGameRun()),
+         this,TQ_SLOT(slotNewGame()));
 }
 
 void Kwin4App::changeAction(const char *action, bool enable){
@@ -542,8 +542,8 @@ void Kwin4App::slotInitNetwork()
   TQVBoxLayout *l=(TQVBoxLayout *)(box->layout());
 
   mColorGroup=new TQVButtonGroup(box);
-  connect(mColorGroup, TQT_SIGNAL(clicked(int)), TQT_TQOBJECT(this), TQT_SLOT(slotRemoteChanged(int)));
-  connect(dlg.networkConfig(), TQT_SIGNAL(signalServerTypeChanged(int)), TQT_TQOBJECT(this), TQT_SLOT(slotServerTypeChanged(int)));
+  connect(mColorGroup, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(slotRemoteChanged(int)));
+  connect(dlg.networkConfig(), TQ_SIGNAL(signalServerTypeChanged(int)), this, TQ_SLOT(slotServerTypeChanged(int)));
 
   new TQRadioButton(i18n("Yellow should be played by remote"), mColorGroup);
   new TQRadioButton(i18n("Red should be played by remote"), mColorGroup);
@@ -590,8 +590,8 @@ void Kwin4App::slotChat()
       mMyChatDlg->setPlayer(doc->getPlayer(Gelb));
     else
       mMyChatDlg->setPlayer(doc->getPlayer(Rot));
-    connect(doc,TQT_SIGNAL(signalChatChanged(Kwin4Player *)),
-            mMyChatDlg,TQT_SLOT(setPlayer(Kwin4Player *)));
+    connect(doc,TQ_SIGNAL(signalChatChanged(Kwin4Player *)),
+            mMyChatDlg,TQ_SLOT(setPlayer(Kwin4Player *)));
   }
   
   if (mMyChatDlg->isHidden())
@@ -619,7 +619,7 @@ void Kwin4App::showSettings(){
   TDEConfigDialog *dialog = new TDEConfigDialog(this, "settings", Prefs::self(), KDialogBase::Swallow);
   Settings *general = new Settings(0, "General");
   dialog->addPage(general, i18n("General"), "package_settings");
-  connect(dialog, TQT_SIGNAL(settingsChanged()), doc, TQT_SLOT(loadSettings()));
+  connect(dialog, TQ_SIGNAL(settingsChanged()), doc, TQ_SLOT(loadSettings()));
   dialog->show();
 }
 
